TOC
Date: 06 23, 2001 5:57:56 PM

CORPORATE ANALYZER
Table of Contents

Pass # | Name | Description
| Intro | Purpose and strategy for building the corporate analyzer
3 | Initial KB | Knowledge Base initialization (Pass: InitKB)
4 | Join | Tokenization and retokenization (Pass: Join)
5-7 | Formatting | Formatting text into chunks (Passes: Sentences, Paragraphs, RemoveWhite)
8-12 | Rule Generation | Working with automatic rule generation in the Gram Tab (Passes: City, Company, State)
13-15 | KB & Dictionary | Dictionaries built by hand (Passes: Lookup, Vocabulary, Phrases)
16-18 | Money | Money phrases and lists (Passes: Money, MoneyAttributes, ConjMoney)
19-21 | Companies | Company phrases (Passes: Companies, CompanyAttributes, CompanyDet)
22-23 | Anaphora | Words that reference previous locations in a text (Passes: Anaphora, AnaphoraCompany)
24 | Company Conj | List of companies in text (Pass: ConjCompany)
25 | Events | Buy, Acquire, and Stock events (Pass: Events)
26-28 | Meta Events | Event attributes and phrases that refer back to other events (Passes: EventAttributes, AnaphoraEvent, Events2)
29 | Output | Outputting the data to a file (Pass: Output)